# QUARK-plugin-mqss

### Provided Modules:

| Module           | Upstream Interface            | Downstream Interface                  |
|------------------|-------------------------------|---------------------------------------|
| circuit_provider | None                          | quark.interface_types.circuit |
| job_execution    | quark.interface_types.circuit | None                                  |
